function [] = gen_harmonic( n, repeat, choose)
% biharmonic equation
% input:
%   n        ... initial grid size (e.g. n=10)
%                (number of variables will be n*n)
%   repeat:  ... how often should grid size be doubled (e.g.repeat=3) 
%                (repeat = 0 means solve for given n only)
% output:
% x,s:       ... optimal solution (final grid)
% Aopt:      ... active set at optimum
% call:   [ x, s, Aopt] = biharmonic( n, repeat);
   
Ain = 1:n^2;          % initial active set
Ain = Ain';
cnt = -1;           % initialize counter
total_time_hr = 0;
total_time_ckr = 0;
total_time_kr = 0;

while cnt < repeat;
  disp(['n= ',int2str(n)]);
  n1 = (n+1)*(n+1);
  [Dn, d, b] = set_harm( n);  % generate data for current n, then solve
  
  if(choose(1) == 1)
      solvetime = tic;
      [x,alpha,iter,Aopt,avg_inact] = kr( Dn, -d/n1, -b, 2, Ain, 10^-10, 1);
      kr_time = toc(solvetime);
      total_time_kr = total_time_kr + kr_time;
      fprintf('\n\n Kunisch-Rendl-Algorithm\n'); % display some info on screen 
      fprintf(' totaltime   atime   anoi  inact_var\n');        
      fprintf(' %3.2f   %3.2f   %3.2f   %3.2f \n\n',total_time_kr,kr_time,iter,avg_inact);
  end
  
  if(choose(2) == 1)
      solvetime = tic;
      [x, alpha, Aopt, dummy, iter, maxfloor, totalsolves, avg_inact] = mkr( Dn, -d/n1, -b, 2, Ain,[], [], 0, 0, 0, 0, 0, 10^-10, 1);
      hr_time = toc(solvetime);
      total_time_hr = total_time_hr + hr_time;
      fprintf('\n\n Modified Kunisch-Rendl-Algorithm\n'); % display some info on screen 
      fprintf('  totaltime  time   anoi   total_solves   mds   inact_var\n');        
      fprintf('   %3.2f     %3.2f   %3.2f   %3.2f    %4d   %3.2f \n\n',total_time_hr,hr_time,iter,totalsolves,maxfloor,avg_inact);
  end
  
  if(choose(3) == 1)
      solvetime = tic;
      [x, alpha, Aopt, Iopt, sum_act, avg_inact, time, oiter, kd, uds, pift, apifu, mpifu, pft, apfu, mpfu, mcountpp] = ckr(Dn, -d/n1, -b, 2, Ain, 10^-10, 1);
      ckr_time = toc(solvetime);
      total_time_ckr = total_time_ckr + ckr_time;
      fprintf('\n\n Controled Kunisch-Rendl-Algorithm\n'); % display some info on screen 
      fprintf(' totaltime time   anoi  heuiter  primup   dualup   maxp   inact var\n');        
      fprintf('  %3.2f    %3.2f   %3.2f   %3.2f      %3.2f     %3.2f      %d     %3.2f\n\n',total_time_ckr,ckr_time,oiter,uds,pift,pft,mcountpp,avg_inact);
  end

  Ain = sparse(n,n,1);       % initialize new active set
  Ain( Aopt) = ones( length( Aopt),1);
  Ain = kron( Ain, ones(2)); % generate guess on active set at refined grid
  Ain = find( Ain > 0);
  cnt = cnt + 1;
  n = 2*n;                   % double size
end



