function [Q,d,u,l,xs,ss] = motobi( n, ncond, ndeg, na);
% generates data according to More, Toraldo: Num Math 55 (1989)
% 377-400: (see page 391)
% input: n ... problem size
%        ncond ... determines condition of Q (ncond > = 0)
%        ndeg ... specifies degeneracy (>0)
%        na ... size of active set at optimum (1,...,n)
%        bilateral case  
% call: [Q,d,u,l,xs,ss] = motobi( n, ncond, ndeg, na);
  
y = 2*rand(n,1)-1;     % random in (-1,1)
Y = eye( n) - 2*y*y'/(y'*y);
d = (0:n-1) * ncond / (n-1);
d = exp( d); 
Q = Y * diag( d) * Y;
Q = (Q+Q')/2;          % the quadratic term

xs = 2*rand(n,1) -1;   % the optimal solution xs
arand = rand(n,1);
active = find(arand <= na/n);
n_act = length( active);  % total number of active constraints
n_half = round( n_act/2);
act_low = active(1: n_half);       % will be at lower bound
act_high = active(n_half+1:n_act); % will be at upper bound
inactive = setdiff( 1:n, active);

mu = rand(n,1) * ndeg;
r = exp( -log(10)*mu);

u = ones(n,1);          % upper bound initialized
l = -u;                 % lower bound initialized
r( inactive) = zeros( length( inactive), 1);
l( act_low) = xs( act_low);

u( act_high) = xs( act_high);
r( act_high) = - r(act_high);

d = Q*xs-r;
ss= -r;





